==> knative-model-4.9.1-sources.jar: io/fabric8/knative/messaging/v1alpha1/InMemoryChannelListFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface InMemoryChannelListFluent<A extends InMemoryChannelListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,InMemoryChannel item);
    public A setToItems(int index,InMemoryChannel item);
    public A addToItems(InMemoryChannel... items);
    public A addAllToItems(Collection<InMemoryChannel> items);
    public A removeFromItems(InMemoryChannel... items);
    public A removeAllFromItems(Collection<InMemoryChannel> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<InMemoryChannel> getItems();
    public List<InMemoryChannel> buildItems();
    public InMemoryChannel buildItem(int index);
    public InMemoryChannel buildFirstItem();
    public InMemoryChannel buildLastItem();
    public InMemoryChannel buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    public A withItems(List<InMemoryChannel> items);
    public A withItems(InMemoryChannel... items);
    public Boolean hasItems();
    public InMemoryChannelListFluent.ItemsNested<A> addNewItem();
    public InMemoryChannelListFluent.ItemsNested<A> addNewItemLike(InMemoryChannel item);
    public InMemoryChannelListFluent.ItemsNested<A> setNewItemLike(int index,InMemoryChannel item);
    public InMemoryChannelListFluent.ItemsNested<A> editItem(int index);
    public InMemoryChannelListFluent.ItemsNested<A> editFirstItem();
    public InMemoryChannelListFluent.ItemsNested<A> editLastItem();
    public InMemoryChannelListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InMemoryChannelFluent<InMemoryChannelListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> knative-model-4.11.0-sources.jar: io/fabric8/knative/messaging/v1alpha1/InMemoryChannelListFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface InMemoryChannelListFluent<A extends InMemoryChannelListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,InMemoryChannel item);
    public A setToItems(int index,InMemoryChannel item);
    public A addToItems(InMemoryChannel... items);
    public A addAllToItems(Collection<InMemoryChannel> items);
    public A removeFromItems(InMemoryChannel... items);
    public A removeAllFromItems(Collection<InMemoryChannel> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<InMemoryChannel> getItems();
    public List<InMemoryChannel> buildItems();
    public InMemoryChannel buildItem(int index);
    public InMemoryChannel buildFirstItem();
    public InMemoryChannel buildLastItem();
    public InMemoryChannel buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    public A withItems(List<InMemoryChannel> items);
    public A withItems(InMemoryChannel... items);
    public Boolean hasItems();
    public InMemoryChannelListFluent.ItemsNested<A> addNewItem();
    public InMemoryChannelListFluent.ItemsNested<A> addNewItemLike(InMemoryChannel item);
    public InMemoryChannelListFluent.ItemsNested<A> setNewItemLike(int index,InMemoryChannel item);
    public InMemoryChannelListFluent.ItemsNested<A> editItem(int index);
    public InMemoryChannelListFluent.ItemsNested<A> editFirstItem();
    public InMemoryChannelListFluent.ItemsNested<A> editLastItem();
    public InMemoryChannelListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InMemoryChannelFluent<InMemoryChannelListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
